@@ -5,6 +5,13 @@
     target_os = "netbsd",
     target_os = "openbsd"
 ))]
+#![allow(
+    clippy::manual_non_exhaustive,
+    clippy::missing_safety_doc,
+    clippy::redundant_static_lifetimes,
+    clippy::unused_unit
+)]
+#![cfg_attr(feature = "cargo-clippy", deny(warnings))]
 
 pub use self::glx::types::GLXContext;
 pub use x11_dl::xlib::*;
